package com.example.e13roomshoppinglist

import androidx.room.ColumnInfo
import androidx.room.Dao
import androidx.room.Database
import androidx.room.Delete
import androidx.room.Entity
import androidx.room.PrimaryKey
import androidx.room.Query
import androidx.room.RoomDatabase
import androidx.room.Upsert
import kotlinx.coroutines.flow.Flow


@Database(
    entities = [ShoppingListItem::class],
    version = 1
)
abstract class ShoppingListDatabase:RoomDatabase() {
    abstract val dao: ShoppingListDao
}


@Entity
data class ShoppingListItem(
    @PrimaryKey(autoGenerate = true)
    val id: Int? = null,

    @ColumnInfo(defaultValue = "")
    val name: String,
    @ColumnInfo(defaultValue = 0.toString())
    val price: Float,
    @ColumnInfo(defaultValue = 0.toString())
    val count: Int,
)


@Dao
interface ShoppingListDao{
    @Upsert
    fun upsertShoppingListItem(shoppingListItem: ShoppingListItem)

    @Delete
    suspend fun deleteShoppingListItem(shoppingListItem: ShoppingListItem)

    @Query("SELECT * FROM ShoppingListItem")
    fun getAllShoppingListItems(): Flow<List<ShoppingListItem>>

    @Query("SELECT * FROM ShoppingListItem ORDER BY name ASC")
    fun getShoppingListItemsOrderedByNameASC(): Flow<List<ShoppingListItem>>
    @Query("SELECT * FROM ShoppingListItem ORDER BY name DESC")
    fun getShoppingListItemsOrderedByNameDESC(): Flow<List<ShoppingListItem>>

    @Query("SELECT * FROM ShoppingListItem ORDER BY price ASC")
    fun getShoppingListItemsOrderedByPriceASC(): Flow<List<ShoppingListItem>>
    @Query("SELECT * FROM ShoppingListItem ORDER BY price DESC")
    fun getShoppingListItemsOrderedByPriceDESC(): Flow<List<ShoppingListItem>>

    @Query("SELECT * FROM ShoppingListItem ORDER BY count ASC")
    fun getShoppingListItemsOrderedByCountASC(): Flow<List<ShoppingListItem>>
    @Query("SELECT * FROM ShoppingListItem ORDER BY count DESC")
    fun getShoppingListItemsOrderedByCountDESC(): Flow<List<ShoppingListItem>>
}
